<?php

declare(strict_types=1);

namespace Drupal\ckeditor_drupalbreaks\Plugin\Filter;

use Drupal\Component\Utility\Html;
use Drupal\filter\FilterProcessResult;
use Drupal\filter\Plugin\FilterBase;

/**
 * Text filter for processing output of the Drupalbreaks CKEditor plugin.
 *
 * @Filter(
 *   id = "drupalbreaks_filter",
 *   title = @Translation("Process the output of the Drupalbreaks CKEditor plugin"),
 *   description = @Translation("Replaces <code>&lt;drupalbreaks&gt;&lt;/drupalbreaks&gt;</code> tag with
 *  <code>&lt;!--break--&gt;</code> to ensure the seperation of teaser and body."),
 *   type = Drupal\filter\Plugin\FilterInterface::TYPE_TRANSFORM_IRREVERSIBLE,
 * )
 */
class DrupalbreaksFilter extends FilterBase {

  /**
   * {@inheritdoc}
   */
  public function process($text, $langcode) {
    return new FilterProcessResult($this->swapBreak($text));
  }

  /**
   * Replace <drupalbreaks></drupalbreaks> tag with <!--break-->.
   *
   * @param string $text
   *   The HTML string to process.
   *
   * @return string
   *   The processed HTML string.
   */
  protected function swapBreak($text) {
    $document = Html::load($text);
    $xpath = new \DOMXPath($document);
    foreach ($xpath->query('//drupalbreaks') as $node) {
      if (!empty($node)) {
        if ($node->parentNode->tagName === 'p' && $node->parentNode->childNodes->length === 1) {
          $node_to_replace = $node->parentNode;
        }
        else {
          $node_to_replace = $node;
        }

        $node_to_replace->parentNode->replaceChild($document->createComment('break'), $node_to_replace);
      }
    }
    return Html::serialize($document);
  }

}

